#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hxt-unicode
version:              9.0.2.4
visibility:           public
id:                   hxt-unicode-9.0.2.4-BsmwfigNSXN6o7aW3shNeo
key:                  hxt-unicode-9.0.2.4-BsmwfigNSXN6o7aW3shNeo
license:              MIT
copyright:            Copyright (c) 2010- Uwe Schmidt
maintainer:           Uwe Schmidt <uwe@fh-wedel.de>
author:               Uwe Schmidt
stability:            Stable
homepage:             https://github.com/UweSchmidt/hxt
synopsis:
    Unicode en-/decoding functions for utf8, iso-latin-* and other encodings

description:
    Unicode encoding and decoding functions for utf8, iso-latin-* and somes other encodings,
    used in the Haskell XML Toolbox.
    ISO Latin 1 - 16, utf8, utf16, ASCII are supported. Decoding
    is done with lazy functions, errors may be detected or ignored.

category:             Text
abi:                  31e2157fed35f162eebf276c47f5dc95
exposed:              True
exposed-modules:
    Data.Char.IsoLatinTables Data.String.EncodingNames Data.String.UTF8
    Data.String.UTF8Decoding Data.String.Unicode

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hxt-unicode-9.0.2.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hxt-unicode-9.0.2.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hxt-unicode-9.0.2.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hxt-unicode
hs-libraries:         HShxt-unicode-9.0.2.4-BsmwfigNSXN6o7aW3shNeo
depends:
    base-4.18.2.1 hxt-charproperties-9.5.0.0-3A2zqKQJ6DvFE2hsaAu0Wc

haddock-interfaces:   /usr/share/doc/haskell-hxt-unicode/html/hxt-unicode.haddock
haddock-html:         /usr/share/doc/haskell-hxt-unicode/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

